@@ -129,8 +129,10 @@ class light_curve(observation):
         self.dump_info()
 
     def dump_info(self):
-        logger.info("The light curve %s has %d bin"%(self._filename_, len(self._times_)))
-        logger.info("The light curve %s has %d GTI bin" % (self._filename_, len(self._gti_start_)))
+        fname = getattr(self, '_filename_', 'none')
+        logger.info("The light curve %s has %d bin" % (fname, len(self._times_)))
+        if hasattr(self, '_gti_start_'):
+            logger.info("The light curve %s has %d GTI bin" % (fname, len(self._gti_start_)))
 
     def from_lc(self, other):
         self._times_ = other._times_
@@ -189,6 +191,47 @@ class light_curve(observation):
 
         return result
 
+    def plot_lc(self, source_name=None, systematic_fraction=0, ng_sig_limit=3):
+        # if ng_sig_limit <1 does not plot range
+        from scipy import stats
+        import matplotlib.pyplot as plt
+        x = self._times_
+        dx = self._timedel_
+        y = self._rates_
+        dy = self._drates_
+        dy = np.sqrt(dy**2 + (y*systematic_fraction)**2)
+
+        meany = np.sum(y / dy ** 2) / np.sum(1. / dy ** 2)
+        err_mean = np.sum(1 / dy ** 2)
+
+        std_dev = np.std(y)
+
+        fig = plt.figure()
+        _ = plt.errorbar(x, y, xerr=dx, yerr=dy, marker='o', capsize=0, linestyle='', label='Lightcurve')
+        _ = plt.axhline(meany, color='green', linewidth=3)
+        _ = plt.xlabel('Time [IJD]')
+        _ = plt.ylabel('Rate')
+
+        if ng_sig_limit >= 1:
+            ndof = len(y) - 1
+            prob_limit = stats.norm().sf(ng_sig_limit)
+            chi2_limit = stats.chi2(ndof).isf(prob_limit)
+            band_width = np.sqrt(chi2_limit / err_mean)
+            # INTEGRALwrapper.__log.debug('%g %g %g %g %g %g %g' % (
+            #     meany, err_mean, std_dev, prob_limit, chi2_limit, band_width, ng_sig_limit))
+            _ = plt.axhspan(meany - band_width, meany + band_width, color='green', alpha=0.3,
+                            label=f'{ng_sig_limit} $\sigma_m$, {100 * systematic_fraction}% syst')
+
+            _ = plt.axhspan(meany - std_dev * ng_sig_limit, meany + std_dev * ng_sig_limit,
+                            color='cyan', alpha=0.3,
+                            label=f'{ng_sig_limit} $\sigma_d$, {100 * systematic_fraction}% syst')
+
+            _ = plt.legend()
+        if source_name is not None:
+            plot_title = source_name
+            _ = plt.title(plot_title)
+
+
     def make_rebin_table(self, min_sn, max_time, gti_threshold, min_bin_size, max_point_sn, single_point_check):
         logger.debug("Making a rebin table for min S/N %f" % min_sn )
         logger.debug("Making a rebin table with GTI threshold %f" % gti_threshold)
